@@ -12,6 +12,7 @@ from .BinaryIsometricOp import BinaryIsometricOp
 from .utils import _create_dask_array
 from .Transpose import Transpose
 from .Cast import Cast
+from .Round import Round
 
 __author__ = "ltla"
 __copyright__ = "ltla"
@@ -204,10 +205,17 @@ class DelayedArray:
         Returns:
             DelayedArray: A ``DelayedArray`` instance containing the requested delayed operation.
         """
-        if ufunc.__name__ in translate_ufunc_to_op_with_args:
+        if (
+            ufunc.__name__ in translate_ufunc_to_op_with_args
+            or ufunc.__name__ == "true_divide"
+        ):
             # This is required to support situations where the NumPy array is on
             # the LHS, such that the ndarray method gets called first.
+
             op = ufunc.__name__
+            if ufunc.__name__ == "true_divide":
+                op = "divide"
+
             first_is_da = isinstance(inputs[0], DelayedArray)
             da = inputs[1 - int(first_is_da)]
             v = inputs[int(first_is_da)]
@@ -254,6 +262,14 @@ class DelayedArray:
                 axes = None
             return DelayedArray(Transpose(seed, perm=axes))
 
+        if func == numpy.round:
+            seed = _extract_seed(args[0])
+            if "decimals" in kwargs:
+                decimals = kwargs["decimals"]
+            else:
+                decimals = 0
+            return DelayedArray(Round(seed, decimals=decimals))
+
         raise NotImplementedError(f"'{func.__name__}' is not implemented!")
 
     def astype(self, dtype, **kwargs):
